==> roundcube_1.5.0+dfsg.1.orig-tinymce.tar.xz: tinymce/modules/bridge/src/main/ts/ephox/bridge/api/PublicMenu.ts <==
import { CardContainerSpec } from '../components/menu/card/CardContainer';
import { CardImageSpec } from '../components/menu/card/CardImage';
import { CardItemSpec } from '../components/menu/card/CardItem';
import { CardTextSpec } from '../components/menu/card/CardText';
import { CardMenuItemInstanceApi, CardMenuItemSpec } from '../components/menu/CardMenuItem';
import { ChoiceMenuItemInstanceApi, ChoiceMenuItemSpec } from '../components/menu/ChoiceMenuItem';
import { ContextMenuApi, ContextMenuContents, ContextMenuItem, ContextSubMenu } from '../components/menu/ContextMenu';
import { FancyMenuItemSpec } from '../components/menu/FancyMenuItem';
import { MenuItemInstanceApi, MenuItemSpec } from '../components/menu/MenuItem';
import { NestedMenuItemContents, NestedMenuItemInstanceApi, NestedMenuItemSpec } from '../components/menu/NestedMenuItem';
import { SeparatorMenuItemSpec } from '../components/menu/SeparatorMenuItem';
import { ToggleMenuItemInstanceApi, ToggleMenuItemSpec } from '../components/menu/ToggleMenuItem';

// These are the types that are exposed though a public end user api

export {
  MenuItemSpec,
  MenuItemInstanceApi,

  NestedMenuItemContents,
  NestedMenuItemSpec,
  NestedMenuItemInstanceApi,

  FancyMenuItemSpec,

  ToggleMenuItemSpec,
  ToggleMenuItemInstanceApi,

  ChoiceMenuItemSpec,
  ChoiceMenuItemInstanceApi,

  SeparatorMenuItemSpec,

  ContextMenuApi,
  ContextMenuContents,
  ContextMenuItem,
  ContextSubMenu,

  CardMenuItemSpec,
  CardMenuItemInstanceApi,

  CardItemSpec,

  CardContainerSpec,
  CardImageSpec,
  CardTextSpec
};

==> roundcube_1.6.6+dfsg.orig-tinymce.tar.xz: tinymce/modules/bridge/src/main/ts/ephox/bridge/api/PublicMenu.ts <==
import { CardContainerSpec } from '../components/menu/card/CardContainer';
import { CardImageSpec } from '../components/menu/card/CardImage';
import { CardItemSpec } from '../components/menu/card/CardItem';
import { CardTextSpec } from '../components/menu/card/CardText';
import { CardMenuItemInstanceApi, CardMenuItemSpec } from '../components/menu/CardMenuItem';
import { ChoiceMenuItemInstanceApi, ChoiceMenuItemSpec } from '../components/menu/ChoiceMenuItem';
import { ContextMenuApi, ContextMenuContents, ContextMenuItem, ContextSubMenu } from '../components/menu/ContextMenu';
import { ColorSwatchMenuItemSpec, FancyMenuItemSpec, InsertTableMenuItemSpec } from '../components/menu/FancyMenuItem';
import { MenuItemInstanceApi, MenuItemSpec } from '../components/menu/MenuItem';
import { NestedMenuItemContents, NestedMenuItemInstanceApi, NestedMenuItemSpec } from '../components/menu/NestedMenuItem';
import { SeparatorMenuItemSpec } from '../components/menu/SeparatorMenuItem';
import { ToggleMenuItemInstanceApi, ToggleMenuItemSpec } from '../components/menu/ToggleMenuItem';

// These are the types that are exposed though a public end user api

export {
  MenuItemSpec,
  MenuItemInstanceApi,

  NestedMenuItemContents,
  NestedMenuItemSpec,
  NestedMenuItemInstanceApi,

  FancyMenuItemSpec,
  ColorSwatchMenuItemSpec,
  InsertTableMenuItemSpec,

  ToggleMenuItemSpec,
  ToggleMenuItemInstanceApi,

  ChoiceMenuItemSpec,
  ChoiceMenuItemInstanceApi,

  SeparatorMenuItemSpec,

  ContextMenuApi,
  ContextMenuContents,
  ContextMenuItem,
  ContextSubMenu,

  CardMenuItemSpec,
  CardMenuItemInstanceApi,

  CardItemSpec,

  CardContainerSpec,
  CardImageSpec,
  CardTextSpec
};
